export declare enum TeamVisibilityType {
    PUBLIC = "public",
    PRIVATE = "private"
}
export declare enum NotePublishType {
    EDIT = "edit",
    VIEW = "view",
    SLIDE = "slide",
    BOOK = "book"
}
export declare enum CommentPermissionType {
    DISABLED = "disabled",
    FORBIDDEN = "forbidden",
    OWNERS = "owners",
    SIGNED_IN_USERS = "signed_in_users",
    EVERYONE = "everyone"
}
export declare type CreateNoteOptions = {
    title?: string;
    content?: string;
    readPermission?: NotePermissionRole;
    writePermission?: NotePermissionRole;
    commentPermission?: CommentPermissionType;
    permalink?: string;
};
export declare type Team = {
    id: string;
    ownerId: string;
    name: string;
    logo: string;
    path: string;
    description: string;
    hardBreaks: boolean;
    visibility: TeamVisibilityType;
    createdAt: Date;
};
export declare type User = {
    id: string;
    email: string | null;
    name: string;
    userPath: string;
    photo: string;
    teams: Team[];
};
export declare type SimpleUserProfile = {
    name: string;
    userPath: string;
    photo: string;
    biography: string | null;
    createdAt: Date;
};
export declare enum NotePermissionRole {
    OWNER = "owner",
    SIGNED_IN = "signed_in",
    GUEST = "guest"
}
export declare type Note = {
    id: string;
    title: string;
    tags: string[];
    lastChangedAt: string;
    createdAt: string;
    lastChangeUser: SimpleUserProfile | null;
    publishType: NotePublishType;
    publishedAt: string | null;
    userPath: string | null;
    teamPath: string | null;
    permalink: string | null;
    shortId: string;
    publishLink: string;
    readPermission: NotePermissionRole;
    writePermission: NotePermissionRole;
};
export declare type SingleNote = Note & {
    content: string;
};
export declare type GetMe = User;
export declare type GetUserNotes = Note[];
export declare type GetUserNote = SingleNote;
export declare type GetUserHistory = Note[];
export declare type CreateUserNote = SingleNote;
export declare type UpdateUserNote = void;
export declare type DeleteUserNote = void;
export declare type GetUserTeams = Team[];
export declare type GetTeamNotes = Note[];
export declare type CreateTeamNote = SingleNote;
export declare type UpdateTeamNote = void;
export declare type DeleteTeamNote = void;
